@@ -21,7 +21,11 @@ from IPython.display import display, HTML
 from IPython import get_ipython
 from noteql.schema_queries import queries
 from urllib.parse import urlencode
-from jinja2.utils import markupsafe
+try:
+    from jinja2.utils import markupsafe
+    Markup = markupsafe.Markup
+except:
+    from jinja2.utils import Markup
 
 
 LOCAL_DB_MADE = False
@@ -96,16 +100,16 @@ def local_db_session(**kw):
 
 
 def safe(value):
-    return markupsafe.Markup(value)
+    return Markup(value)
 
 
 def identity(value):
-    return markupsafe.Markup(f""" "{value.replace('"', '""')}" """)
+    return Markup(f""" "{value.replace('"', '""')}" """)
 
 
 def fields(values):
     fields = ",".join(f""" "{value.replace('"', '""')}" """ for value in values)
-    return markupsafe.Markup(f"{fields}")
+    return Markup(f"{fields}")
 
 
 class Session:
